# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-05-01 18:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qna', '0011_question_has_answer'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='question',
            options={'ordering': ['-created_at'], 'verbose_name': 'Вопрос', 'verbose_name_plural': 'Вопросы'},
        ),
        migrations.AlterField(
            model_name='question',
            name='last_update',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]
