# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-24 15:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qna', '0002_auto_20160424_1425'),
    ]

    operations = [
        migrations.AddField(
            model_name='question',
            name='_target',
            field=models.BooleanField(default=True),
        ),
    ]
