# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-25 10:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('review', '0005_review_last_update'),
    ]

    operations = [
        migrations.CreateModel(
            name='ReviewList',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('target_id', models.PositiveIntegerField()),
                ('_target', models.BooleanField(default=True)),
                ('count', models.IntegerField(default=0)),
                ('sum', models.IntegerField(default=0)),
                ('avg', models.FloatField(default=0)),
                ('target_content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterModelOptions(
            name='review',
            options={},
        ),
        migrations.AlterUniqueTogether(
            name='review',
            unique_together=set([]),
        ),
        migrations.AddField(
            model_name='review',
            name='review_list',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to='review.ReviewList'),
        ),
    ]
