# -*- coding: utf-8 -*-
# Generated by Django 1.9.3 on 2016-04-27 11:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('review', '0007_auto_20160427_0959'),
    ]

    operations = [
        migrations.AlterField(
            model_name='review',
            name='_id',
            field=models.CharField(blank=True, max_length=24, null=True),
        ),
        migrations.AlterUniqueTogether(
            name='reviewlist',
            unique_together=set([('target_content_type', 'target_id')]),
        ),
    ]
